@@ -10,6 +10,7 @@ import inspect
 import copy
 
 from .globaling import *
+from .odicting import odict
 
 from . import aiding
 from . import excepting
@@ -21,49 +22,40 @@ from .consoling import getConsole
 console = getConsole()
 
 
-def CreateInstances(store):
-    """Create action instances
-       must be function so can recreate after clear registry
-    """
-    transiter = Transiter(name = 'transiter', store = store)
-    suspender = Suspender(name = 'suspender', store = store)
-    deactivator = Deactivator(name = 'deactivator', store = store)
-    restarter = Restarter(name = 'restarter', store = store)
-    printer = Printer(name = 'printer', store = store)
-    markerUpdate = UpdateMarker(name = 'markerUpdate', store = store)
-    markerChange = ChangeMarker(name = 'markerChange', store = store)
-
 #Class definitions
 
 class Act(object):
-    """lightweight container class for action references and parameters
+    """ Container class for actor resolve time initialization and runtime operation """
+    __slots__ = ('frame', 'context', 'act',
+                 'actor', 'registrar', 'parms', 'inits', 'ioinits', 'action')
 
-    """
-    __slots__ = ('actor', 'parms', 'frame', 'context', 'act', 'iois')
-
-    def __init__(self, actor=None, parms=None, frame=None, context=None,
-                     act=None, iois=None, **kwa ):
+    def __init__(self, frame=None, context=None, act=None, actor=None, registrar=None,
+                 parms=None, inits=None, ioinits=None, action='', **kwa ):
         """ Initialization method for instance.
 
-            attributes
-                .actor = Actor instance callable , call performs instances method action
-                .parms = dictionary of keyword arguments for .act
-                .frame = Frame reference to frame holding act
-                .context = Action execution context name string set when added to frame
-                .act = Act reference if act in embedded in another act such as Need
-                .iois = dictionary of share initializers of parms with same key
-
+            Attributes:
+            .frame = ref to Frame holding this Act
+            .context = name string of actioning context set when added to frame
+            .act = ref to super Act if self is embedded in another Act such as Need
+            .actor = ref to Actor instance or actor name to be resolved
+                    call performs instances method action
+            .registrar = ref to Actor class holding .Registry 
+            .parms = dictionary of keyword arguments for Actor instance call
+            .inits = dictionary of arguments to Actor.__init__()
+            .ioinits = dictionary of arguments to Actor.initio()
+            .action = string name of Actor method to call
         """
         super(Act,self).__init__()
 
-        self.actor = actor #callable instance performs action
-        self.parms = parms or {}
         self.frame = frame
         self.context = context
         self.act = act
-        self.iois = iois
-        
-        self.parms['_act'] = self
+        self.actor = actor #callable instance performs action
+        self.registrar = registrar or Actor
+        self.parms = parms or odict()       
+        self.inits = inits or odict()
+        self.ioinits = ioinits or odict()
+        self.action = action # default call
 
     def __call__(self): #make Act instance callable as function
         """ Define act as callable object """
@@ -71,10 +63,31 @@ class Act(object):
 
     def expose(self):
         """ Show attributes"""
-        cconsole.terse("Act Actor {0} Parms {1} in Frame {2} Context {3} SuperAct {4}\n".format(
+        console.terse("Act Actor {0} Parms {1} in Frame {2} Context {3} SuperAct {4}\n".format(
                     self.actor, self.parms, self.frame, self.context, self.act))
         if self.actor:
             self.actor.expose()
+    
+    def resolve(self, **kwa):
+        """ Resolve .frame attribute and .actor. Cause .actor to resolve its parms """
+        if self.act: # this is sub act of another act self.act so get super act context
+            self.frame = self.act.frame
+            self.context = self.act.context
+        self.frame = framing.resolveFrame(self.frame, who=self)
+        
+        if not isinstance(self.actor, Actor): # Need to resolve .actor
+            actor, inits, ioinits = self.registrar.__fetch__(self.actor)
+            inits.update(self.inits)
+            if 'name' not in inits:
+                inits['name'] = self.actor
+            inits['store'] = self.frame.store
+            inits['act'] = self
+            self.actor = actor(**inits)
+            self.ioinits.create(ioinits) #fill in defaults
+            
+        parms = self.actor.resolve(**self.parms)
+        self.parms.update(parms)
+        self.actor.postinitio(**self.parms)
             
     def clone(self, clones):
         """ Return clone of self in support of framer cloning
@@ -89,48 +102,26 @@ class Act(object):
         """ Fixup parms in actor for framer cloning.
             clones is dict whose items keys are original framer names
             and values are are duples of (original,clone) framer references
-            
         """
         parms = self.actor.cloneParms(parms=self.parms, clones=clones)
         self.parms.update(parms)
-
-    def resolveLinks(self, *pa, **kwa):
-        """ Resolve .frame attribute and any links in associated parms for .actor"""
-        if self.act: # sub act such as need of another act .act
-            self.frame = self.act.frame
-            self.context = self.act.context
-        self.frame = framing.resolveFrame(self.frame, who=self)
-        
-        parms = self.actor.resolveLinks(**self.parms)
-        self.parms.update(parms) 
-
+    
 class Nact(Act):
     """ Negating Act used for actor needs to give Not Need
     """
-    __slots__ = ('actor', 'parms', 'frame', 'context', 'act', 'iois')
+    __slots__ = ('frame', 'context', 'act',
+                 'actor', 'registrar', 'parms', 'inits', 'ioinits', 'action')
 
     def __init__(self, **kwa ):
-        """ Initialization method for instance.
-
-            Inherited attributes
-                .actor = Actor instance callable , call performs instances method action
-                .parms = dictionary of keyword arguments for .act
-                .frame = Frame reference to frame holding act
-                .context = Action execution context name string
-                .act = Act reference if act in embedded in another act such as Need
-                .iois = dictionary of share initializers of parms with same key
-
-        """
+        """ Initialization method for instance. """
         super(Nact,self).__init__(**kwa)
 
-
     def __call__(self): #make Act instance callable as function
         """Define act as callable object
            Negate the output
         """
         return not (self.actor(**self.parms))
 
-
     def expose(self):
         """ Show attributes """
         console.terse("Nact Actor {0} Parms {1} in Frame {2} Context {3} SuperAct {4}\n".format(
@@ -138,50 +129,331 @@ class Nact(Act):
         if self.actor:
             self.actor.expose()
 
-
-class Actor(registering.StoriedRegistry):
-    """Actor Patron Registry Class 
-       for executing actions
-       via its action method 
+class Actor(object): # old registering.StoriedRegistry
+    """ Actor Base Class
+        Has Actor specific Registry of classes
     """
-    Counter = 0  
-    Names = {}
-
-    def __init__(self, name = '', **kwa ):
+    __metaclass__ = registering.RegisterType
+    Registry = odict() # Actor Registry
+    Ioinits = odict() # class defaults
+    _Parametric = True # Convert iois to action method parameters if Truthy
+    __slots__ = ('name', 'store', 'act')
+    
+    @classmethod
+    def actify(cls, name, parms=None, inits=None, ioinits=None):
+        """ Return new Act using the class specific registry to get Actor class
+            from name and defaults for parms, inits, and ioinits
+            Updates defaults with passed in parms, inits, ioinits
+        """
+        inits = inits or odict()
+        ioinits = ioinits or odict()
+        # fetch actor and default copies of inits and ioinits from registry
+        actor, rinits, rioinits = cls.__fetch__(name)
+        inits.create(rinits) # set defaults of missing
+        if 'name' not in inits:
+            inits['name'] = name
+        ioinits.create(rioinits) # set defaults of missing
+        return Act(actor=actor, parms=parms, inits=inits, ioinits=ioinits)
+    
+    def __init__(self, name='', store=None, act=None, **kwa ):
         """ Initialization method for instance.
 
-            inherited attributes
-                .name = unique name for actor instance
-                .store = shared data store
-              
-            The registry class will supply unique name when name is empty by using
-            the .__class__.__name__ as the default preface to the name.
-            To use a different default preface add this to the .__init__ method
-            before the super call
-            
-            if 'preface' not in kw:
-                kw['preface'] = 'MyDefaultPreface'
-
-
+            Instance attributes
+                .name = name string for Actor variant in class Registry
+                .store = reference to shared data Store
+                .act = reference to containing Act
         """
-        super(Actor,self).__init__(name = name, **kwa)
-    
+        self.name = name
+        if store is not None: 
+            if  not isinstance(store, storing.Store):
+                raise ValueError("Not store %s" % store)
+            self.store = store
+        self.act = act
+        
     def __call__(self, **kwa):
-        """run .action
-
-        """
+        """ run .action  """
         return self.action(**kwa)
     
     def action(self, **kwa):
         """Action called by Actor. Should override in subclass."""
         console.profuse("Actioning {0} with {1}\n".format(self.name, str(kwa)))
-
         pass
     
     def expose(self):
         """Show Actor."""
-        console.terse("Actor {0}".format(self.name))
+        console.terse("Actor {0}".format(self.name))    
+    
+    def resolve(self, **kwa):
+        """ Return updated parms from conversion of .act.ioinits into iois and
+            resolution into share refs if any.
+            Based on ._Parametric convert resolve iois to attributes or parms
+            Extend in subclass to resolve specific kwa items that are links or
+            share refs and update parms
+        """
+        parms = odict()
+        if self.act.ioinits:
+            iois = self.initio(**self.act.ioinits)
+            if iois:
+                for key, ioi in iois.items():
+                    share = self.resolvePath(    ipath=ioi['ipath'],
+                                                 ival=ioi.get('ival'), 
+                                                 iown=ioi.get('iown'))
+                    if self._Parametric:
+                        if key in kwa:
+                            msg = "ResolveError: Parm and Ioi with same name"
+                            raise excepting.ResolveError(msg, key, self)
+                        parms[key] = share                            
+                    else:
+                        if hasattr(self, key):
+                            msg = "ResolveError: Attribute and Ioi with same name"
+                            raise excepting.ResolveError(msg, key, self) 
+                        setattr(self, key, share)                            
+        return parms    
+    
+    def initio(self, inode='', **kwa):
+        """ Intialize and hookup ioflo shares from node pathname inode and kwa arguments.
+            This implements a generic Actor interface protocol for associating the
+            io data flow shares to the Actor.
+            
+            inode is the computed pathname string of the default share node
+            where shares associated with the Actor instance may be placed when
+            relative addressing is used.
+            
+            The values of the items in the **kwa argument may be either strings or
+            mappings
+            
+            For each key,val in **kwa.items() there are the following 2 forms for val:
+            
+            1- string:
+               ipath = pathnamestring
+            2- dict of items (mapping) of form:
+                {
+                    ipath: "pathnamestring", (optional)
+                    ival: initial value, (optional)
+                    iown: truthy, (optional)
+                }
+            
+            In either case, three init values are produced, these are:
+                ipath, ival, iown,
+            Missing init values from ipath, ival, iown will be assigned a
+            default value as per the rules below:
+
+            For each kwa item (key, val)
+                key is the name of the associated instance attribute or action parm.
+                Extract ipath, ival, iown from val
+                
+                Shares are initialized with mappings passed into share.create or
+                share.update. So to assign ival to share.value pass into share.create
+                or share.update a mapping of the form {'value': ival} whereas
+                passing in an empty mapping does nothing.
+                
+                If ipath not provided
+                    ipath is the default path inode.key
+                Else ipath is provided
+                    If ipath starts with dot "." Then absolute path
+                    Else ipath does not start with dot "." Then relative path from inode
+                        
+                    If ipath ends with dot Then the path is to a node not share
+                            node ref is created and remaining init values are ignored 
+
+                
+                If ival not provided
+                     set ival to empty mapping which when passed to share.create
+                     will not change share.value
+                Else ival provided
+                    If ival is an empty Mapping Then
+                        assign a shallow copy of ival to share.value by passing
+                        in {value: ival (copy)} to share.create/.update
+                    Else If ival is a non-string iterable and not a mapping
+                        assign a shallow copy of ival to share.value by passing
+                        in {value: ival (copy)} to share.create/.update 
+                    Else If ival is a non-empty Mapping Then
+                        Each item in ival is assigned as a field, value pair in the share
+                        by passing ival directly into share.create or share.update
+                        This means there is no way to init a share.value to a non empty mapping
+                        It is possible to init a share.value to an empty mapping see below
+                    Else
+                        assign ival to share.value by by passing
+                        in {value: ival} to share.create or share.update
+
+                Create share with pathname given by ipath
+
+                If iown Then
+                    init share with ival value using update 
+                Else
+                    init share with ival value using create ((change if not exist))
+                
+        """
+        if not isinstance(inode, basestring):
+            raise ValueError("Nonstring inode arg '{0}'".format(inode))
         
+        if not inode:
+            inode = aiding.nameToPath(self.name)
+        
+        if not inode.endswith('.'):
+            inode = "{0}.".format(inode)        
+        
+        iois = odict()
+        
+        for key, val in kwa.items():
+            if val == None:
+                continue
+            
+            if isinstance(val, basestring):
+                ipath = val
+                iown = None
+                ival = odict() # effectively will not change share
+            elif isinstance(val, Mapping): # dictionary
+                ipath = val.get('ipath')
+                iown = val.get('iown')
+                
+                if not 'ival' in val:
+                    ival = odict() # effectively will not change share
+                else:
+                    ival = val['ival']
+                    if isinstance(ival, Mapping):
+                        if not ival: #empty mapping
+                            ival = odict(value=copy.copy(ival)) #make copy so each instance unique
+                        # otherwise don't change since ival is non-empty mapping
+                    elif isinstance(ival, NonStringIterable): # not mapping and NonStringIterable
+                        ival = odict(value=copy.copy(ival))
+                    else: 
+                        ival = odict(value=ival)                    
+            else:
+                raise ValueError("Bad init kw arg '{0}'with Value '{1}'".format(key, val))
+            
+            if ipath:
+                if not ipath.startswith('.'): # full path is inode joined to ipath
+                    ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
+            else:
+                ipath = '.'.join(inode.rstrip('.'), key)    
+            ioi = odict(ipath=ipath, ival=ival, iown=iown)
+            iois[key] = ioi
+        
+        ioi = odict(ipath=inode)
+        iois['inode'] = ioi
+        
+        return iois # non-empty when _parametric
+    
+    def postinitio(self, **kwa):
+        """ Base method to be overriden in sub classes. Perform post initio setup
+            after all parms and ioi parms or attributes have been created
+            kwa usually parms
+        """
+        pass    
+    
+    def resolvePath(self, ipath, ival=None, iown=None):
+        """ Returns resolved Share or Node instance from ipath
+            ipath may be path name of share or node
+            or reference to Share or Node instance
+
+            This method resolves pathname strings into share and node references
+            at resolve time.
+            
+            It allows for substitution into ipath of
+            frame, framer, main frame, or main framer relative names.
+            So that lexically relative pathnames can
+            be dynamically resolved in support of framer cloning.
+            It assumes that any implied variants have been reconciled.
+            
+            When ipath is a string:  (not a Node or Share reference)
+                the following syntax is used:
+            
+                If the path name starts with a leading '.' dot then path name is
+                fully reconciled and no contextual substitutions are to be applied.
+            
+                Otherwise make subsitutions in pathname strings that begin
+                with 'framer.' and have the special framer and/or frame names
+                of 'me' or 'main'.
+            
+                'me' indicates substitute the current framer or frame name respectively.
+                
+                'main' indicates substitute the current frame's main framer or main frame
+                name respectively.
+            
+            When  ipath is a pathname string that resolves to a Share and ival is not None
+            Then ival is used to initialize the share values.
+                ival should be a dict of fields and values
+                
+                If own is True then .update(ival) is used
+                Otherwise .create(ival) is used
+            
+            Requires that
+               self.name is not empty
+               self.store exist
+               self.act exist
+               
+               The following have already been resolved:
+               self.act.frame
+               self.act.frame.framer 
+               self.act.frame.framer.main
+               self.act.frame.framer.main.framer
+            
+        """    
+        if not (isinstance(ipath, storing.Share) or isinstance(ipath, storing.Node)): # must be pathname
+            if not ipath.startswith('.'): # not reconciled so do relative substitutions
+                parts = ipath.split('.')
+                if parts[0] == 'framer':  #  relative addressing
+                    if not self.act:
+                        raise excepting.ResolveError("ResolveError: Missing act context"
+                                " to resolve relative pathname.", ipath, self)
+                    if not self.act.frame:
+                        raise excepting.ResolveError("ResolveError: Missing frame context"
+                            " to resolve relative pathname.", ipath, self.act)
+                    if not self.act.frame.framer:
+                        raise excepting.ResolveError("ResolveError: Missing framer context"
+                            " to resolve relative pathname.", ipath, self.act.frame)
+                    
+                    if parts[1] == 'me': # current framer
+                        parts[1] = self.act.frame.framer.name
+                    elif parts[1] == 'main': # current main framer
+                        if not self.act.frame.framer.main:
+                            raise excepting.ResolveError("ResolveError: Missing main frame"
+                                " context to resolve relative pathname.", ipath,
+                                self.act.frame.framer)
+                        parts[1] = self.act.frame.framer.main.framer.name
+                    
+                    if (len(parts) >= 3):
+                        if parts[2] == 'frame':
+                            if parts[3] == 'me':
+                                parts[3] = self.frame.name
+                            elif parts[3] == 'main':
+                                if not self.act.frame.framer.main:
+                                    raise excepting.ResolveError("ResolveError: "
+                                        "Missing main frame context to resolve "
+                                        "relative pathname.", ipath,
+                                        self.act.frame.framer)
+                                parts[3] = self.act.frame.framer.main.name
+                            if (len(parts) >= 5 ) and parts[4] == 'actor':
+                                if parts[5] == 'me': # slice insert multiple parts
+                                    if not self.name:
+                                        raise excepting.ResolveError("ResolveError: Missing name"
+                                            " context to resolve relative pathname.", ipath, self)                                        
+                                    parts[5:6] = nameToPath(self.name).rstrip('.').split('.')
+                        elif parts[2] == 'actor':
+                            if parts[3] == 'me': # slice insert multiple parts
+                                if not self.name:
+                                    raise excepting.ResolveError("ResolveError: Missing name"
+                                        " context to resolve relative pathname.", ipath, self)                                
+                                parts[3:4] = nameToPath(self.name).rstrip('.').split('.')                        
+                
+                ipath = '.'.join(parts)
+            
+            if not self.store:
+                raise excepting.ResolveError("ResolveError: Missing store context"
+                                " to resolve relative pathname.", ipath, self)                
+            if ipath.endswith('.'): # Node not Share
+                ipath = self.store.createNode(ipath.rstrip('.'))
+            else: # Share
+                ipath = self.store.create(ipath)
+                if ival != None:
+                    if iown:
+                        ipath.update(ival)
+                    else:
+                        ipath.create(ival)
+                    
+        return ipath        
+     
     def clone(self):
         """ Clone self in support of framer cloning.
             Actors that are fully parametrized work as singletons so just return
@@ -231,27 +503,8 @@ class Actor(registering.StoriedRegistry):
                         newShare.create(stuff)
                         parms[key] = newShare                    
 
-        return parms      
-    
-    def resolveLinks(self, _act, **kwa):
-        """ Resolves any links in parms for Actor
-            should be overridden by sub class
-        """
-        parms =  {}
-
-        if _act.iois:
-            for key, ioi in _act.iois.items():
-                if key in kwa:
-                    raise excepting.ResolveError("ResolveError: Parm and Ioi with same key", key, _act)
-                
-                parms[key] = storing.resolvePath(   store=self.store,
-                                                    ipath=ioi['ipath'],
-                                                    ival=ioi.get('ival'), 
-                                                    iown=ioi.get('iown'),
-                                                    act=_act)
         return parms
-
-
+    
 class Interrupter(Actor):
     """Interrupter Actor Patron Registry Class 
        Interrupter is a base clase for all actor classes that interrupt normal precur
@@ -329,6 +582,42 @@ class Transiter(Interrupter):
     def expose(self):
         """      """
         console.terse("Transiter {0}\n".format(self.name))
+    
+    def resolve(self, needs, near, far, human, **kwa):
+        """Resolve any links in far and in associated parms for actors"""
+
+        parms = super(Transiter, self).resolve( **kwa)  
+        
+        if not isinstance(near, framing.Frame):
+            if near not in framing.Frame.Names:
+                raise excepting.ResolveError("ResolveError: Bad near link",
+                                            human, near)
+            parms['near'] = near = framing.Frame.Names[near] #replace name with valid link        
+
+        if not isinstance(far, framing.Frame):
+            if far == 'next':
+                if not isinstance(near.next, framing.Frame):
+                    raise excepting.ResolveError("ResolveError: Bad next frame",
+                                                 near.name, near.next)
+                far = near.next
+
+            elif far == 'me':
+                far = near
+
+            elif far in framing.Frame.Names:
+                far = framing.Frame.Names[far]
+
+            else:
+                raise excepting.ResolveError("ResolveError: Bad far link",
+                                             near.name + " " + human, far)
+
+            parms['far'] = far #replace name with valid link
+
+        for act in needs:
+            act.act = self.act
+            act.resolve()
+
+        return parms    
         
     def cloneParms(self, parms, clones, **kw):
         """ Returns parms fixed up for framing cloning. This includes:
@@ -360,43 +649,6 @@ class Transiter(Interrupter):
         
         return parms    
         
-    def resolveLinks(self, _act, needs, near, far, human, **kw):
-        """Resolve any links in far and in associated parms for actors"""
-
-        parms = {}
-        
-        if not isinstance(near, framing.Frame):
-            if near not in framing.Frame.Names:
-                raise excepting.ResolveError("ResolveError: Bad near link",
-                                            human, near)
-            parms['near'] = near = framing.Frame.Names[near] #replace name with valid link        
-
-        if not isinstance(far, framing.Frame):
-            if far == 'next':
-                if not isinstance(near.next, framing.Frame):
-                    raise excepting.ResolveError("ResolveError: Bad next frame",
-                                                 near.name, near.next)
-                far = near.next
-
-            elif far == 'me':
-                far = near
-
-            elif far in framing.Frame.Names:
-                far = framing.Frame.Names[far]
-
-            else:
-                raise excepting.ResolveError("ResolveError: Bad far link",
-                                             near.name + " " + human, far)
-
-            parms['far'] = far #replace name with valid link
-
-        for act in needs:
-            act.act = _act
-            act.resolveLinks()
-
-        return parms
-
-
 class Suspender(Interrupter):
     """Suspender Interrupter Actor Patron Registry Class 
        Suspender  is a special actor that performs a conditional auxiliary
@@ -478,6 +730,33 @@ class Suspender(Interrupter):
 
         aux.exitAll() # also sets .done = True
         aux.main = None
+    
+    def resolve(self, needs, main, aux, human, **kwa):
+        """Resolve any links aux and in associated parms for actors"""
+        parms = super(Suspender, self).resolve( **kwa) 
+        
+        if not isinstance(main, framing.Frame):
+            if main not in framing.Frame.Names:
+                raise excepting.ResolveError("ResolveError: Bad main link", human, main)
+            parms['main'] = main = framing.Frame.Names[main] #replace name with valid link                    
+
+        if not isinstance(aux, framing.Framer):
+            if aux not in framing.Framer.Names:
+                raise excepting.ResolveError("ResolveError: Bad aux link",
+                                                main.name + " " + human, aux)                
+                
+            parms['aux'] = aux = framing.Framer.Names[aux] #replace name with valid link
+            console.terse("    Resolved aux as {0} in {1}".format(aux.name, main.name))
+
+        if aux.schedule != AUX:
+            raise excepting.ResolveError("ResolveError: Bad aux link not scheduled as AUX",
+                                         main.name + " " + human, aux)
+
+        for act in needs:
+            act.act = self.act
+            act.resolve()
+
+        return parms    
 
     def cloneParms(self, parms, clones, **kw):
         """ Returns parms fixed up for framing cloning. This includes:
@@ -515,60 +794,48 @@ class Suspender(Interrupter):
         
         return parms
 
-    def resolveLinks(self, _act, needs, main, aux, human, **kw):
-        """Resolve any links aux and in associated parms for actors"""
-
-        parms = {}
-        
-        if not isinstance(main, framing.Frame):
-            if main not in framing.Frame.Names:
-                raise excepting.ResolveError("ResolveError: Bad main link", human, main)
-            parms['main'] = main = framing.Frame.Names[main] #replace name with valid link                    
-
-        if not isinstance(aux, framing.Framer):
-            if aux not in framing.Framer.Names:
-                raise excepting.ResolveError("ResolveError: Bad aux link",
-                                                main.name + " " + human, aux)                
-                
-            parms['aux'] = aux = framing.Framer.Names[aux] #replace name with valid link
-            console.terse("    Resolved aux as {0} in {1}".format(aux.name, main.name))
-
-        if aux.schedule != AUX:
-            raise excepting.ResolveError("ResolveError: Bad aux link not scheduled as AUX",
-                                         main.name + " " + human, aux)
-
-        for act in needs:
-            act.act = _act
-            act.resolveLinks()
-
-        return parms
-
-
 class Deactivator(Actor):
     """Deactivator Actor Patron Registry Class 
 
        Deactivator is a special actor that acts on an Act
 
        In the Deactivator's action method, 
-          IF the act passed in as a parameter has an _activate attribute THEN
-                       it calls the deactivate method
+          IF the act passed in as a parameter .actor has an _activate attribute THEN
+                       it calls the deactivate method its .actor
        This is to ensure the outline in cond aux is exited cleanly when the aux
           is preempted by higher level transition.
 
        Builder adds a deactivator for each Suspender preact
     """
-    def action(self, actor, aux, **kw):
+    def action(self, act, aux, **kw):
         """Action called by Actor
         """
         #console.profuse("{0} action {1} for {2}\n".format(self.name, actor.name, aux.name))
 
-        if hasattr(actor, '_activative') and not aux.done:
-            console.profuse("{0} deactivate {1} for {2}\n".format(self.name, actor.name, aux.name))
-            return actor.deactivate(aux)
+        if hasattr(act.actor, '_activative') and not aux.done:
+            console.profuse("{0} deactivate {1} for {2}\n".format(self.name, act.actor.name, aux.name))
+            return act.actor.deactivate(aux)
 
     def expose(self):
         """   """
         console.terse("Deactivator {0}\n".format(self.name))
+    
+    def resolve(self, aux, **kwa):
+        """Resolve aux link parm"""
+        parms = super(Deactivator, self).resolve( **kwa) 
+
+        if not isinstance(aux, framing.Framer):
+            if aux not in framing.Framer.Names:
+                raise excepting.ResolveError("ResolveError: Bad aux link",
+                                                             aux, self.name)                
+            parms['aux'] = aux = framing.Framer.Names[aux] #replace name with valid link
+            console.terse("    Resolved aux as {0}".format(aux.name))
+
+        if aux.schedule != AUX:
+            msg = "ResolveError: Bad deactivator aux link not scheduled as AUX"
+            raise excepting.ResolveError(msg, aux.name, self.name)
+
+        return parms    
         
     def cloneParms(self, parms, clones, **kw):
         """ Returns parms fixed up for framing cloning. This includes:
@@ -599,50 +866,29 @@ class Deactivator(Actor):
 
         return parms
               
-    def resolveLinks(self, actor, aux, **kw):
-        """Resolve any links aux and in associated parms for actors"""
-
-        parms = {}
-
-        if not isinstance(aux, framing.Framer):
-            if aux not in framing.Framer.Names:
-                raise excepting.ResolveError("ResolveError: Bad far link",
-                                                             near.name + " " + human, far)                
-            parms['aux'] = aux = framing.Framer.Names[aux] #replace name with valid link
-            console.terse("    Resolved aux as {0}".format(aux.name))
-
-        if aux.schedule != AUX:
-            msg = "ResolveError: Bad deactivator aux link not scheduled as AUX"
-            raise excepting.ResolveError(msg, actor.name, aux)
-
-        return parms
-
 class Restarter(Actor):
-    """RestarterActor Patron Registry Class 
-
-       Restarter is a special actor that acts on other actor
-       In the Restarter's action method, 
-       if the actor passed in as a parameter has a restart attribute
-          it calls the restart method
-
-       Builder checks at parse time
-       If deed instance has restart attribute then
-          adds enter restarter action for the deed
+    """ Restarter is a special actor that acts on other act's actor
+        In the Restarter's action method, 
+            if the act.actor passed in as a parameter has a restart attribute
+                 it calls the act.actor.restart() method
+          
+        Doesn't need to resolve its action method's 'act' parm because the act has
+        own entry in Frame it will get resolved normally
+        
+        Restarter act is created in .resolve of Deed's that need restarting.
     """
-    def action(self, actor, **kw):
-        """Action called by Actor
+    def action(self, act, **kw):
+        """ Action called by Actor
         """
-        console.profuse("{0} restart {1}\n".format(self.name, actor.name))
+        console.profuse("{0} restart {1}\n".format(self.name, act.actor.name))
 
-        if hasattr(actor, 'restart'):
-            return actor.restart()
+        if hasattr(act.actor, 'restart'):
+            return act.actor.restart()
 
     def expose(self):
         """   """
         console.terse("Restarter {0}\n".format(self.name))
-
-
-
+    
 class Printer(Actor):
     """Printor Actor Patron Registry Class 
 
@@ -679,13 +925,7 @@ class Marker(Actor):
         
         #don't need to do anything yet since rerefShares will reref
 
-        return parms    
-    
-    def resolveLinks(self, share, name, **kw):
-        """Resolves share and adds mark in share"""
-        parms = {}
-            
-        return parms    
+        return parms       
         
 class UpdateMarker(Marker):
     """ UpdateMarker Class 
@@ -698,18 +938,18 @@ class UpdateMarker(Marker):
         Builder at parse time when it encounters an UpdateNeed,
         creates the mark in the share and creates the appropriate UpdateMarker 
     """
-    def action(self, share, name, **kw):
+    def action(self, share, frame, **kwa):
         """ Update mark in share
-            Where share is reference to share and name is frame name key of mark in
+            Where share is reference to share and frame is frame name key of mark in
                 share.marks odict
             Updates mark.stamp
             
             only one mark per frame per share is needed 
         """
         console.profuse("{0} mark {1} in {2} on {3}\n".format(
-            self.name, share.name, name, 'update' ))
+            self.name, share.name, frame, 'update' ))
 
-        mark = share.marks.get(name)
+        mark = share.marks.get(frame)
         if mark:
             mark.stamp = self.store.stamp #stamp when marker runs
 
@@ -728,18 +968,18 @@ class ChangeMarker(Marker):
         Builder at parse time when it encounters a ChangeNeed,
         creates the mark in the share and creates the appropriate marker 
     """
-    def action(self, share, name, **kw):
+    def action(self, share, frame, **kwa):
         """ Update mark in share
-            Where share is reference to share and name is frame name key of mark in
+            Where share is reference to share and frame is frame name key of mark in
                 share.marks odict
             Updates mark.data
             
             only one mark per frame per share is needed 
         """
         console.profuse("{0} mark {1} in {2} on {3}\n".format(
-            self.name, share.name, name, 'change' ))
+            self.name, share.name, frame, 'change' ))
 
-        mark = share.marks.get(name)
+        mark = share.marks.get(frame)
         if mark:
             mark.data = storing.Data(share.items())
 
