@@ -5,14 +5,51 @@
 
 import random
 
-
 from .globaling import *
+from .odicting import odict
 
 from . import excepting
+from .aiding import reverseCamel
 
 from .consoling import getConsole
 console = getConsole()
 
+class RegisterType(type):
+    """ Metaclass that registers all subclasses """
+    def __init__(cls, name, bases, attrs):
+        """ Create if needed and register cls into Registry under reverse of name """
+        super(RegisterType, cls).__init__(name, bases, attrs)
+        if not hasattr(cls, 'Registry'):
+            cls.Registry = odict()
+        rname = reverseCamel(name)
+        cls.__register__(rname, ioinits=getattr(cls, 'Ioinits', None))
+    
+    def __register__(cls, rname, inits=None,  ioinits=None):
+        """ Register cls under rname with ioinits and inits
+        
+            Usage:  A.__register__(rname, ioinits, inits)
+        """
+        if rname in cls.Registry:
+            msg = "Entry '{0}' already exists in registry of {1}".format(rname, cls)
+            raise excepting.RegisterError(msg)
+        inits = inits or odict()
+        ioinits = ioinits or odict()
+        cls.Registry[rname] = (cls, inits, ioinits)
+        #console.terse( "Registered class '{0}' under '{1}' with {2} per {3}.\n".format(
+            #cls.__name__, rname, inits, ioinits))        
+        return cls
+    
+    def __fetch__(cls, rname):
+        """ Return tuple derived from .Registry entry at rname if present
+            Otherwise raise exception
+            Makes copies of inits and ioinits so safe for downstream use
+        """
+        if rname not in cls.Registry:
+            msg = "Entry '{0}' not found in Registry of '{1}'".format(rname, cls.__name__)
+            raise excepting.RegisterError(msg)
+        actor, inits, ioinits = cls.Registry[rname]
+        return (actor, odict(inits), odict(ioinits))
+        
 class Registry(object):
     """Class that ensures every instance has a unique name
        uses class variable Counter and  Names dictionary
@@ -105,26 +142,4 @@ class StoriedRegistry(Registry):
                 raise ValueError("Not store %s" % store)
         self.store = store        
 
-def Test():
-    """Module self test
-
-
-
-    """
-    
-    x = Registry()
-    print x.name
-    y = Registry()
-    print y.name
-
-    name = "Hello"
-    if Registry.VerifyName(name):
-        z = Registry(name= name)
-    print Registry.Names
-    print Registry.VerifyName(name)
-
-
-
-if __name__ == "__main__":
-    Test()
 
